<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Config;

class ContactForm extends Mailable
{
    use Queueable, SerializesModels;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct($inputFullName, $inputEmail, $inputPhone, $inputMessage, $inputFile, $confirmation = false)
    {
        $this->inputFullName = $inputFullName;
        $this->inputEmail = $inputEmail;
        $this->inputPhone = $inputPhone;
        $this->inputMessage = $inputMessage;
        $this->inputFile = $inputFile;

        $this->confirmation = $confirmation;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        $title = $this->confirmation ? "wiadomość wysłana" : "formularz kontaktowy";
        $mailer = $this
            ->markdown('emails.contact')
            ->subject(sprintf('%s - %s', config('app.name'), $title))
//            ->from(config('mail.mailers.smtp.username'))
            ->with([
                'inputFullName' => $this->inputFullName,
                'inputEmail' => $this->inputEmail,
                'inputPhone' => $this->inputPhone,
                'inputMessage' => $this->inputMessage,
                'confirmation' => $this->confirmation,
            ]);

        if (!$this->confirmation) {
            $mailer->replyTo($this->inputEmail);
        }

        if ($this->inputFile) {
            $extension = $this->inputFile->extension();
            $mailer->attach($this->inputFile->getRealPath(), [
                'as' => pathinfo($this->inputFile, PATHINFO_FILENAME) . '.' . $extension,
                'mime' => $this->inputFile->getMimeType(),
            ]);
        }

        return $mailer;

//        return $this->view('emails.contact')->subject($this->confirmation ? "Wiadomość wysłana - " . config('app.name') : "Formularz kontaktowy - " . config('app.name'))->from(Config::get('mail.from.address'), Config::get('mail.from.name'))->with([
//            'inputFullName' => $this->inputFullName,
//            'inputEmail' => $this->inputEmail,
//            'inputPhone' => $this->inputPhone,
//            'inputMessage' => $this->inputMessage,
//
//            'confirmation' => $this->confirmation,
//        ]);
    }
}
