<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Sushi\Sushi;

class Service extends Model
{
    use HasFactory;
    use Sushi;

    public function getRows() {
        return [
            [
                'id' => 1,
                'title' => 'Projektowanie mechaniczne',
                'slug' => 'projektowanie-mechaniczne',
                'short_description' => 'Tworzymy projekty, od koncepcji po finalne modele.',
                'description' => 'Nasza firma oferuje kompleksowe i precyzyjne usługi projektowania CAD, wykorzystując najnowocześniejsze narzędzia i technologie. Tworzymy innowacyjne projekty, od koncepcji po finalne modele, zapewniając rozwiązania dopasowane do unikalnych potrzeb klientów. Nasz proces projektowania charakteryzuje się następującymi etapami:',
                'icon' => '
                <svg id="Page-1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 30.169 30.122">
                    <g id="_021---3D-Design-Software" data-name="021---3D-Design-Software" transform="translate(0 0)">
                        <path id="Shape" d="M28.66,3.52H21.377L15.336.067a.5.5,0,0,0-.5,0L8.792,3.52H1.508A1.508,1.508,0,0,0,0,5.028v18.6a1.508,1.508,0,0,0,1.508,1.508h9.044A3.242,3.242,0,0,1,9.4,27.2H9.051a1.462,1.462,0,0,0,0,2.924H21.118a1.462,1.462,0,0,0,0-2.924h-.352a3.242,3.242,0,0,1-1.149-2.058H28.66a1.508,1.508,0,0,0,1.508-1.508V5.028A1.508,1.508,0,0,0,28.66,3.52ZM8.548,5.392,14.582,8.84v6.386L8.548,11.776ZM15.587,8.84l6.034-3.448v6.386l-6.034,3.446Zm-.5-7.757,6.026,3.443L15.084,7.969,9.058,4.525ZM21.667,28.66a.549.549,0,0,1-.549.549H9.051a.549.549,0,0,1,0-1.1H21.118A.549.549,0,0,1,21.667,28.66ZM19.5,27.2H10.672a4.592,4.592,0,0,0,.8-2.058h7.22A4.592,4.592,0,0,0,19.5,27.2Zm9.163-3.063H1.508a.5.5,0,0,1-.5-.5V22.627H3.017a.5.5,0,1,0,0-1.006H1.006V5.028a.5.5,0,0,1,.5-.5H7.542v7.252L5.361,13.034l.238-.888a.5.5,0,1,0-.973-.258L4.073,13.95a.5.5,0,0,0,.355.616l2.062.553a.51.51,0,0,0,.13.018.5.5,0,0,0,.13-.989l-.888-.238,2.183-1.262,6.537,3.734V18.9l-.65-.65a.5.5,0,0,0-.711.711l1.508,1.508a.5.5,0,0,0,.711,0l1.508-1.508a.5.5,0,0,0-.711-.711l-.65.65V16.382l6.537-3.734,2.182,1.26-.888.238a.5.5,0,0,0,.129.99.51.51,0,0,0,.13-.018l2.062-.553a.5.5,0,0,0,.355-.616l-.553-2.062a.5.5,0,0,0-.971.26l.238.888-2.181-1.258V4.525H28.66a.5.5,0,0,1,.5.5V21.621H5.028a.5.5,0,1,0,0,1.006H29.163v1.006a.5.5,0,0,1-.5.5Z" transform="translate(0 0)" fill="#07beb8"/>
                    </g>
                </svg>
                ',
                'steps' => json_encode([
                    [
                        'title' => 'Definicja Problemu i Analiza Wymagań',
                        'description' => 'Rozpoczynamy od zrozumienia i zdefiniowania problemu inżynieryjnego. W tym etapie zbieramy wymagania, specyfikacje i ograniczenia projektowe, konsultując się regularnie z klientem, aby zapewnić zgodność z jego oczekiwaniami.',
                    ],
                    [
                        'title' => 'Poszukiwanie najlepszych rozwiązań',
                        'description' => 'Przeprowadzamy burzę mózgów, poszukujemy rozwiązań i technologii. Na tej podstawie tworzymy wstępne koncepcje, które mogą rozwiązać postawiony problem, uwzględniając przy tym sugestie i opinie klienta.',
                    ],
                    [
                        'title' => 'Szkicowanie i Projektowanie Wstępne',
                        'description' => 'Nasi projektanci, w ścisłej współpracy z klientem, tworzą wstępne koncepcje, które następnie są analizowane pod kątem ich wykonalności. Wspólnie wybieramy najlepsze rozwiązanie.',
                    ],
                    [
                        'title' => 'Modelowanie 3D w CAD',
                        'description' => 'Wybrana koncepcja jest przekształcana w szczegółowe modele 3D przy użyciu oprogramowania CAD. Dokonujemy niezbędnych obliczeń i modelujemy wszystkie elementy, nadając im ostateczne wymiary. Otrzymujemy w pełni zdefiniowany produkt.',
                    ],
                    [
                        'title' => 'Analiza i Symulacja',
                        'description' => 'Jeśli istnieje konieczność, poddajemy zaprojektowany przedmiot dodatkowym obliczeniom. Przeprowadzamy symulacje i analizy MES (metodą elementów skończonych), aby ocenić wydajność i bezpieczeństwo projektu. Na podstawie wyników, projekt jest modyfikowany i optymalizowany.',
                    ],
                    [
                        'title' => 'Tworzenie Dokumentacji Technicznej',
                        'description' => 'Po finalizacji projektu, tworzymy szczegółową dokumentację techniczną zgodnie ze standardami ISO - GPS oraz ASME - GD&T. Dokumentacja ta zawiera rysunki wykonawcze 2D, BOM (listę części) i specyfikacje materiałowe. Przeprowadzamy analizuję tolerancji wymiarów, aby zagwarantować poprawne wykonanie i montaż wyrobu.',
                    ],
                    [
                        'title' => 'Raport z wykonanych prac',
                        'description' => 'Na koniec naszej pracy sporządzamy raport podsumowujący nasze działania. Wraz z nim przekazujemy klientowi pełną dokumentację techniczną we wcześniej uzgodnionych formatach.',
                    ],
                ]),
                'date' => '04.02.2024',
                'order' => 10,
                'status' => true,
            ],
            [
                'id' => 2,
                'title' => 'Doradztwo techniczne',
                'slug' => 'doradztwo-techniczne',
                'short_description' => 'Rozwiązujemy skomplikowane wyzwania inżynieryjne.',
                'description' => 'Zespół naszych ekspertów oferuje wysokiej jakości doradztwo techniczne, pomagając klientom w rozwiązywaniu najbardziej skomplikowanych wyzwań inżynieryjnych. Nasza wiedza i doświadczenie są kluczem do osiągnięcia optymalnych rezultatów',
                'icon' => '
                <svg id="Layer_1" enable-background="new 0 0 512 512" viewBox="0 0 512 512" xmlns="http://www.w3.org/2000/svg"><path d="m207.678 399.267c-13.156-11.898-28.606-20.624-45.244-25.756 17.648-11.61 29.33-31.581 29.33-54.24 0-35.781-29.11-64.891-64.892-64.891s-64.891 29.11-64.891 64.891c0 22.658 11.681 42.629 29.33 54.24-16.639 5.132-32.089 13.858-45.245 25.756-22.018 19.911-35.875 47.064-39.021 76.458-.242 2.257.487 4.51 2.004 6.199 1.517 1.688 3.68 2.652 5.95 2.652h223.744c2.27 0 4.433-.964 5.95-2.653 1.517-1.688 2.246-3.941 2.004-6.198-3.144-29.394-17.002-56.547-39.019-76.458zm-129.696-79.995c0-26.958 21.933-48.891 48.891-48.891 26.959 0 48.892 21.933 48.892 48.891 0 26.954-21.926 48.884-48.878 48.891-.004 0-.009 0-.013 0s-.009 0-.013 0c-26.954-.008-48.879-21.937-48.879-48.891zm-53.701 149.304c9.42-48.705 52.047-84.408 102.581-84.413h.01s.007 0 .01 0c50.534.005 93.16 35.708 102.581 84.413zm436.615-69.309c-13.156-11.898-28.606-20.625-45.245-25.756 17.648-11.61 29.329-31.581 29.329-54.239 0-35.781-29.11-64.891-64.891-64.891s-64.892 29.11-64.892 64.891c0 22.658 11.682 42.63 29.331 54.24-16.638 5.132-32.088 13.858-45.244 25.756-22.018 19.911-35.875 47.063-39.021 76.457-.242 2.257.487 4.51 2.004 6.198s3.68 2.653 5.95 2.653h223.744c2.27 0 4.433-.964 5.95-2.652s2.246-3.942 2.004-6.199c-3.144-29.394-17.002-56.547-39.019-76.458zm-129.699-79.995c0-26.958 21.933-48.891 48.892-48.891 26.958 0 48.891 21.933 48.891 48.891 0 26.954-21.925 48.883-48.878 48.891-.004 0-.009 0-.013 0s-.009 0-.013 0c-26.953-.007-48.879-21.937-48.879-48.891zm-53.699 149.303c9.42-48.705 52.046-84.408 102.58-84.413h.01.01c50.535.005 93.162 35.708 102.582 84.413zm196.562-441.151h-208.814c-15.958 0-28.94 12.983-28.94 28.94v48.927c-1.081.866-1.955 1.999-2.476 3.351l-4.277 11.111c-5.901 1.724-11.588 4.082-16.988 7.043l-1.567-.696v-63.4c0-16.001-13.018-29.019-29.019-29.019h-144.421c-16 0-29.018 13.018-29.018 29.019v102.565c0 16.001 13.018 29.019 29.018 29.019h11.007l35.263 35.708c1.533 1.553 3.595 2.379 5.694 2.379 1.022 0 2.053-.196 3.036-.6 3.002-1.232 4.962-4.156 4.962-7.4v-30.087h57.921v19.458c0 3.31 2.038 6.277 5.126 7.466l11.106 4.275c1.724 5.906 4.083 11.595 7.045 16.995l-4.833 10.883c-1.344 3.025-.686 6.564 1.654 8.904l17.233 17.233c2.339 2.34 5.878 2.998 8.904 1.655l10.889-4.836c5.399 2.961 11.086 5.32 16.988 7.043l4.276 11.11c1.188 3.089 4.156 5.126 7.466 5.126h24.371c3.31 0 6.277-2.038 7.466-5.126l4.275-11.106c5.906-1.724 11.595-4.083 16.995-7.045l10.883 4.833c3.026 1.343 6.564.686 8.904-1.654l17.233-17.233c2.34-2.34 2.998-5.879 1.655-8.904l-4.836-10.889c2.962-5.4 5.32-11.087 7.043-16.988l11.11-4.277c3.089-1.188 5.126-4.156 5.126-7.466v-24.371c0-.646-.099-1.272-.247-1.882h63.018v29.946c0 3.245 1.96 6.168 4.962 7.4.983.404 2.014.6 3.036.6 2.099 0 4.161-.826 5.694-2.379l35.123-35.567h10.954c15.958 0 28.94-12.982 28.94-28.94v-102.183c0-15.958-12.982-28.941-28.94-28.941zm-384.54 150.86c-4.418 0-8 3.582-8 8v18.601l-23.919-24.222c-1.503-1.522-3.553-2.379-5.692-2.379h-14.35c-7.178 0-13.018-5.84-13.018-13.019v-102.565c0-7.178 5.84-13.019 13.018-13.019h144.42c7.179 0 13.019 5.84 13.019 13.019v59.363c-.809.385-1.567.894-2.225 1.552l-17.232 17.233c-2.34 2.34-2.998 5.879-1.655 8.904l4.835 10.887c-2.962 5.4-5.32 11.087-7.044 16.99l-1.701.655zm246.001 29.965-9.794 3.77c-2.462.947-4.298 3.047-4.909 5.614-1.695 7.122-4.507 13.905-8.358 20.159-1.383 2.247-1.57 5.03-.499 7.441l4.265 9.602-9.465 9.465-9.597-4.262c-2.412-1.073-5.197-.885-7.443.5-6.251 3.851-13.036 6.663-20.164 8.359-2.566.611-4.667 2.447-5.614 4.909l-3.769 9.791h-13.385l-3.77-9.794c-.947-2.462-3.047-4.298-5.614-4.909-7.123-1.695-13.905-4.507-20.159-8.357-2.245-1.383-5.03-1.57-7.441-.5l-9.602 4.265-9.465-9.465 4.262-9.597c1.071-2.412.884-5.196-.5-7.443-3.851-6.251-6.663-13.036-8.359-20.164-.611-2.566-2.447-4.667-4.909-5.614l-9.791-3.769v-13.386l9.793-3.77c2.462-.947 4.298-3.047 4.909-5.614 1.695-7.124 4.508-13.907 8.358-20.16 1.383-2.247 1.57-5.031.5-7.442l-4.264-9.6 9.465-9.465 9.602 4.265c2.412 1.07 5.195.884 7.441-.5 6.254-3.851 13.037-6.663 20.159-8.358 2.566-.611 4.666-2.447 5.613-4.909l3.771-9.795h13.385l3.77 9.794c.947 2.462 3.047 4.298 5.613 4.909 7.123 1.695 13.906 4.507 20.16 8.358 2.246 1.382 5.029 1.569 7.441.5l9.602-4.265 9.465 9.465-4.262 9.597c-1.071 2.411-.884 5.196.5 7.442 3.851 6.253 6.663 13.037 8.359 20.164.611 2.566 2.447 4.667 4.909 5.614l9.791 3.769zm151.479-49.7c0 7.135-5.805 12.94-12.94 12.94h-14.297c-2.139 0-4.189.857-5.692 2.379l-23.779 24.08v-18.459c0-4.418-3.582-8-8-8h-89.06c-1.405-3.725-3.068-7.351-4.989-10.854l4.833-10.884c.525-1.181.735-2.439.668-3.675h127.356c4.418 0 8-3.582 8-8s-3.582-8-8-8h-140.45l-6.462-6.461c-2.34-2.34-5.879-2.997-8.904-1.655l-10.889 4.836c-5.399-2.962-11.086-5.32-16.988-7.043l-2.147-5.578c.912.361 1.903.566 2.944.566h182.895c4.418 0 8-3.582 8-8s-3.582-8-8-8h-182.894c-3.846 0-7.055 2.714-7.823 6.331-1.342-.982-2.978-1.556-4.716-1.556h-13.361v-47.151c0-7.135 5.805-12.94 12.94-12.94h208.815c7.135 0 12.94 5.805 12.94 12.94zm-17.899-83.143c0 4.418-3.582 8-8 8h-182.896c-4.418 0-8-3.582-8-8s3.582-8 8-8h182.895c4.419 0 8.001 3.581 8.001 8zm-325.806 18.501c0 11.271-7.665 18.178-13.823 23.728-5.923 5.338-9.57 8.885-9.889 14.306-.25 4.251-3.775 7.531-7.979 7.531-.158 0-.317-.004-.477-.014-4.411-.259-7.776-4.045-7.517-8.456.72-12.25 8.721-19.46 15.15-25.253 5.291-4.768 8.534-7.891 8.534-11.842 0-9.665-7.863-17.527-17.527-17.527s-17.527 7.862-17.527 17.527c0 4.418-3.582 8-8 8s-8-3.582-8-8c0-18.487 15.04-33.527 33.527-33.527s33.528 15.041 33.528 33.527zm-23.7 57.412c0 4.418-3.582 8-8 8s-8-3.582-8-8 3.582-8 8-8 8 3.581 8 8zm133.886.092c-27.65 0-50.146 22.495-50.146 50.145s22.495 50.146 50.146 50.146 50.146-22.495 50.146-50.146c-.001-27.65-22.496-50.145-50.146-50.145zm0 84.29c-18.828 0-34.146-15.317-34.146-34.146 0-18.828 15.317-34.145 34.146-34.145s34.146 15.317 34.146 34.145c-.001 18.829-15.318 34.146-34.146 34.146z"/></svg>
                ',
                'steps' => json_encode([]),
                'date' => '04.02.2024',
                'order' => 20,
                'status' => true,
            ],
            [
                'id' => 3,
                'title' => 'Skanowanie 3D',
                'slug' => 'skanowanie-3d',
                'short_description' => 'Precyzyjnie odwzorowujemy obiekty przy użyciu skanera 3D.',
                'description' => 'W Cadictive specjalizujemy się w zaawansowanym skanowaniu 3D, dostarczając usługi na najwyższym poziomie dla różnych sektorów rynku. Wykorzystując nowoczesne technologie skanowania i fotogrametrii, jesteśmy w stanie przenosić przedmioty z rzeczywistości do cyfrowego świata z imponującą dokładnością.<br>Nasza oferta skanowania 3D obejmuje szeroki zakres przedmiotów - od delikatnych i detalicznych figur dekoracyjnych, poprzez skomplikowane komponenty techniczne, aż do całych przestrzeni ładunkowych pojazdów. Oferujemy profesjonalne usługi skanowania dla przedmiotów codziennego użytku, a także unikalnych dekoracji i pamiątek. Nasze skany 3D są nieocenione przy projektowaniu dedykowanych zabudów, klatek bezpieczeństwa, elementów tuningu oraz przy tworzeniu innowacyjnych rozwiązań dostosowanych do indywidualnych wymagań klienta. Oferujemy digitalizację dziedzictwa kulturowego - skanujemy eksponaty muzealne, umożliwiając ich konserwację i badanie w formie cyfrowej, a także otwierając dostęp do nich dla szerszej publiczności. Wykorzystujemy także skanowanie 3D w celu tworzenia pamiątek, jak na przykład figurek dla kobiet w ciąży, przenosząc te wyjątkowe chwile do trwałej formy cyfrowej.',
                'icon' => '
                <svg id="_x31_px" enable-background="new 0 0 24 24" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path d="m23.5 24h-3c-.276 0-.5-.224-.5-.5v-3c0-.276.224-.5.5-.5h3c.276 0 .5.224.5.5v3c0 .276-.224.5-.5.5zm-2.5-1h2v-2h-2z"/><path d="m3.5 24h-3c-.276 0-.5-.224-.5-.5v-3c0-.276.224-.5.5-.5h3c.276 0 .5.224.5.5v3c0 .276-.224.5-.5.5zm-2.5-1h2v-2h-2z"/><path d="m23.5 4h-3c-.276 0-.5-.224-.5-.5v-3c0-.276.224-.5.5-.5h3c.276 0 .5.224.5.5v3c0 .276-.224.5-.5.5zm-2.5-1h2v-2h-2z"/><path d="m3.5 4h-3c-.276 0-.5-.224-.5-.5v-3c0-.276.224-.5.5-.5h3c.276 0 .5.224.5.5v3c0 .276-.224.5-.5.5zm-2.5-1h2v-2h-2z"/><path d="m2 21c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5z"/><path d="m22 21c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5zm0-5c-.276 0-.5-.224-.5-.5v-2c0-.276.224-.5.5-.5s.5.224.5.5v2c0 .276-.224.5-.5.5z"/><path d="m20.5 22.5h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5z"/><path d="m20.5 2.5h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5zm-5 0h-2c-.276 0-.5-.224-.5-.5s.224-.5.5-.5h2c.276 0 .5.224.5.5s-.224.5-.5.5z"/><path d="m12 11c-.061 0-.122-.011-.18-.033l-6.5-2.5c-.193-.074-.32-.26-.32-.467s.127-.393.32-.467l6.5-2.5c.115-.044.244-.044.359 0l6.5 2.5c.194.074.321.26.321.467s-.127.393-.32.467l-6.5 2.5c-.058.022-.119.033-.18.033zm-5.107-3 5.107 1.964 5.107-1.964-5.107-1.964z"/><path d="m12 19c-.061 0-.122-.011-.18-.033l-6.5-2.5c-.193-.074-.32-.26-.32-.467v-8c0-.276.224-.5.5-.5s.5.224.5.5v7.657l6 2.308 6-2.308v-7.657c0-.276.224-.5.5-.5s.5.224.5.5v8c0 .207-.127.393-.32.467l-6.5 2.5c-.058.022-.119.033-.18.033z"/><path d="m12 19c-.276 0-.5-.224-.5-.5v-8c0-.276.224-.5.5-.5s.5.224.5.5v8c0 .276-.224.5-.5.5z"/></svg>
                ',
                'steps' => json_encode([
                    [
                        'title' => 'Konsultacje i Analiza Potrzeb Klienta',
                        'description' => 'Rozpoczynamy od szczegółowych konsultacji z klientem, aby zrozumieć jego potrzeby i wymagania dotyczące skanowania. Określamy cel skanowania, wymagany poziom szczegółowości oraz preferowany format danych wyjściowych.',
                    ],
                    [
                        'title' => 'Przygotowanie do Skanowania',
                        'description' => 'Przygotowujemy obiekt do skanowania, co może obejmować czyszczenie, aplikowanie matowej powłoki (w przypadku błyszczących lub przezroczystych powierzchni) oraz ustawienie obiektu w optymalnej pozycji. Dbamy o to, aby środowisko skanowania było odpowiednie do uzyskania najwyższej jakości danych.',
                    ],
                    [
                        'title' => 'Proces Skanowania',
                        'description' => 'Używamy zaawansowanych skanerów 3D do digitalizacji obiektu. Proces ten może być przeprowadzony za pomocą różnych metod, w zależności od rozmiaru, kształtu i właściwości obiektu. Dokładnie skanujemy każdy aspekt, aby uzyskać kompletny i precyzyjny obraz 3D.',
                    ],
                    [
                        'title' => 'Przetwarzanie Danych',
                        'description' => 'Po skanowaniu przetwarzamy zebrane dane, co obejmuje ich oczyszczanie, usuwanie szumów i niepożądanych elementów. Dopracowujemy model, aby był zgodny z wymaganiami klienta.',
                    ],
                    [
                        'title' => 'Dostarczenie Wyników',
                        'description' => 'Dane otrzymane w wyniku skanowania dostarczamy klientowi w wybranym formacie np. OBJ, PLY, STL, DXF, XML, STEP, IGES, X_T, SAT. ',
                    ]
                ]),
                'date' => '04.02.2024',
                'order' => 30,
                'status' => true,
            ],
            [
                'id' => 4,
                'title' => 'Dokumentacja techniczna 2D',
                'slug' => 'dokumentacja-techniczna-2d',
                'short_description' => 'Tworzymy dokumentację techniczną 2D.',
                'description' => 'Oferujemy kompleksowe usługi tworzenia dokumentacji technicznej 2D, gwarantując precyzję i czytelność. Tworzymy dokumentację w standardach ISO GPS oraz ASME GD&T. ',
                'icon' => '
                <svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                     viewBox="0 0 512.001 512.001" style="enable-background:new 0 0 512.001 512.001;" xml:space="preserve">
                        <g>
                            <g>
                                <path d="M447.229,67.855h-43.181v-43.18C404.049,11.103,392.944,0,379.379,0H64.771C51.2,0,40.097,11.103,40.097,24.675V419.47
                                    c0,13.571,11.103,24.675,24.675,24.675h43.181v43.181c0,13.571,11.098,24.675,24.675,24.675h209.729
                                    c13.565,0,32.762-7.612,42.638-16.908l68.929-64.882c9.888-9.296,17.969-28.012,17.969-41.583l0.012-296.096
                                    C471.904,78.959,460.8,67.855,447.229,67.855z M107.951,92.531v333.108h-43.18c-3.343,0-6.168-2.825-6.168-6.168V24.675
                                    c0-3.343,2.825-6.168,6.168-6.168H379.38c3.337,0,6.168,2.825,6.168,6.168v43.181H132.626
                                    C119.049,67.856,107.951,78.959,107.951,92.531z M441.24,416.737l-68.929,64.877c-1.412,1.327-3.251,2.628-5.281,3.867v-56.758
                                    c0-4.238,1.709-8.051,4.528-10.888c2.844-2.819,6.656-4.533,10.894-4.533h61.718C443.213,414.602,442.233,415.799,441.24,416.737z
                                     M453.385,388.626c0,1.832-0.334,3.954-0.839,6.168h-70.095c-18.721,0.037-33.89,15.206-33.928,33.928v64.024
                                    c-2.202,0.445-4.324,0.746-6.168,0.746H132.626v0.001c-3.35,0-6.168-2.825-6.168-6.168V92.53c0-3.343,2.819-6.168,6.168-6.168
                                    h314.602c3.343,0,6.168,2.825,6.168,6.168L453.385,388.626z"/>
                            </g>
                        </g>
                    <g>
                        <g>
                            <path d="M379.379,154.216H200.488c-5.114,0-9.253,4.139-9.253,9.253c0,5.114,4.14,9.253,9.253,9.253h178.891
                                    c5.108,0,9.253-4.139,9.253-9.253S384.487,154.216,379.379,154.216z"/>
                        </g>
                    </g>
                    <g>
                        <g>
                            <path d="M379.379,277.59H200.488c-5.114,0-9.253,4.139-9.253,9.253c0,5.114,4.14,9.253,9.253,9.253h178.891
                                    c5.108,0,9.253-4.139,9.253-9.253C388.632,281.728,384.487,277.59,379.379,277.59z"/>
                        </g>
                    </g>
                    <g>
                        <g>
                            <path d="M299.187,339.277h-98.698c-5.114,0-9.253,4.139-9.253,9.253s4.139,9.253,9.253,9.253h98.698
                                    c5.108,0,9.247-4.139,9.247-9.253S304.295,339.277,299.187,339.277z"/>
                        </g>
                    </g>
                    <g>
                        <g>
                            <path d="M379.379,215.903H200.488c-5.114,0-9.253,4.139-9.253,9.253s4.14,9.253,9.253,9.253h178.891
                                    c5.108,0,9.253-4.139,9.253-9.253S384.487,215.903,379.379,215.903z"/>
                        </g>
                    </g>
                </svg>
                ',
                'steps' => json_encode([]),
                'date' => '04.02.2024',
                'order' => 40,
                'status' => true,
            ],
            [
                'id' => 5,
                'title' => 'Inżynieria odwrotna',
                'slug' => 'inzynieria-odwrotna',
                'short_description' => 'Realizujemy innowacyjne projekty, od koncepcji po finalne modele.',
                'description' => 'W naszej firmie oferujemy specjalistyczne usługi inżynierii odwrotnej, które umożliwiają analizę, odtwarzanie i głębokie zrozumienie złożonych konstrukcji i produktów. Stosujemy inżynierię odwrotną, aby wspierać innowacyjność i rozwój produktów naszych klientów. Nasz proces inżynierii odwrotnej obejmuje następujące etapy:',
                'icon' => '
                <svg
                    version="1.1"
                    id="svg2325"
                    xml:space="preserve"
                    viewBox="0 0 682.66669 682.66669"
                    xmlns="http://www.w3.org/2000/svg"
                    xmlns:svg="http://www.w3.org/2000/svg"><defs
                        id="defs2329"><clipPath
                            clipPathUnits="userSpaceOnUse"
                            id="clipPath2339"><path
                                d="M 0,512 H 512 V 0 H 0 Z"
                                id="path2337" /></clipPath></defs><g
                        id="g2331"
                        transform="matrix(1.3333333,0,0,-1.3333333,0,682.66667)"><g
                            id="g2333"><g
                                id="g2335"
                                clip-path="url(#clipPath2339)"><g
                                    id="g2341"
                                    transform="translate(372.5195,233.0693)"><path
                                        d="m 0,0 -11.019,6.362 c -5.867,3.387 -9.345,9.684 -9.336,16.459 v 0.11 0.11 c -0.009,6.774 3.469,13.072 9.336,16.459 l 11.02,6.362 c 8.539,4.931 11.465,15.85 6.535,24.389 l -20.548,35.589 c -4.93,8.539 -15.85,11.465 -24.389,6.535 l -11.028,-6.367 c -5.783,-3.339 -12.914,-3.348 -18.683,0.015 -0.222,0.129 -0.445,0.258 -0.669,0.386 -5.789,3.313 -9.337,9.493 -9.337,16.163 v 12.734 c 0,9.86 -7.994,17.854 -17.855,17.854 h -41.094 c -9.86,0 -17.853,-7.994 -17.853,-17.854 v -12.734 c 0,-6.67 -3.549,-12.849 -9.338,-16.162 -0.224,-0.128 -0.447,-0.257 -0.669,-0.387 -5.769,-3.363 -12.901,-3.354 -18.684,-0.015 l -11.028,6.367 c -8.539,4.93 -19.458,2.004 -24.388,-6.535 l -20.548,-35.59 c -4.93,-8.539 -2.004,-19.458 6.535,-24.388 l 11.02,-6.362 c 5.867,-3.388 9.345,-9.685 9.337,-16.459 v -0.11 -0.11 c 0.008,-6.774 -3.47,-13.072 -9.337,-16.459 L -233.04,0 c -8.539,-4.93 -11.465,-15.85 -6.535,-24.389 l 20.548,-35.589 c 4.93,-8.54 15.849,-11.465 24.388,-6.535 l 11.028,6.367 c 5.783,3.339 12.914,3.348 18.683,-0.015 0.223,-0.13 0.446,-0.259 0.67,-0.387 5.789,-3.312 9.338,-9.492 9.338,-16.163 v -12.732 c 0,-9.861 7.993,-17.855 17.854,-17.855 h 41.093 c 9.861,0 17.855,7.994 17.855,17.855 v 12.732 c 0,6.671 3.548,12.851 9.337,16.163 0.224,0.128 0.447,0.257 0.669,0.387 5.769,3.363 12.901,3.354 18.684,0.015 l 11.027,-6.367 c 8.539,-4.929 19.459,-2.005 24.389,6.535 L 6.536,-24.389 C 11.465,-15.85 8.54,-4.93 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2343" /></g><g
                                    id="g2345"
                                    transform="translate(299.4185,256)"><path
                                        d="m 0,0 c 0,-23.979 -19.439,-43.418 -43.418,-43.418 -23.98,0 -43.419,19.439 -43.419,43.418 0,23.979 19.439,43.419 43.419,43.419 C -19.439,43.419 0,23.979 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2347" /></g><g
                                    id="g2349"
                                    transform="translate(501.3462,273.8311)"><path
                                        d="m 0,0 c -2.456,33.96 -11.921,67.509 -28.416,98.289 -28.21,-21.04 -68.31,-18.739 -93.93,6.88 -25.62,25.62 -27.92,65.721 -6.88,93.931 -82.97,44.46 -186.06,37.92 -263.1,-19.621 5.43,-6.259 8.71,-14.429 8.71,-23.36 0,-19.7 -15.98,-35.68 -35.68,-35.68 -8.93,0 -17.1,3.281 -23.36,8.71 -57.54,-77.04 -64.08,-180.129 -19.62,-263.099 28.21,21.04 68.31,18.739 93.93,-6.881 25.62,-25.619 27.92,-65.72 6.88,-93.93 82.78,-44.36 185.59,-37.95 262.58,19.24 -5.14,6.18 -8.22,14.111 -8.22,22.77 0,19.71 15.97,35.681 35.68,35.681 8.73,0 16.73,-3.141 22.93,-8.351 18.026,23.982 31.09,50.508 39.199,78.178"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2351" /></g><g
                                    id="g2353"
                                    transform="translate(480.8965,379)"><path
                                        d="m 0,0 c -28.138,-28.138 -73.758,-28.138 -101.896,0 -28.138,28.138 -28.138,73.759 0,101.896 28.138,28.138 73.758,28.138 101.896,0 C 28.138,73.759 28.138,28.138 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2355" /></g><g
                                    id="g2357"
                                    transform="translate(133,31.1035)"><path
                                        d="m 0,0 c -28.138,-28.138 -73.759,-28.138 -101.896,0 -28.139,28.138 -28.139,73.759 0,101.896 28.137,28.138 73.758,28.138 101.896,0 C 28.138,73.759 28.138,28.138 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2359" /></g><g
                                    id="g2361"
                                    transform="translate(53.2515,77.9971)"><path
                                        d="M 0,0 19.005,-19.005 57.016,19.006"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2363" /></g><g
                                    id="g2365"
                                    transform="translate(403.3213,428.0674)"><path
                                        d="M 0,0 19.005,-19.006 57.016,19.005"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2367" /></g><g
                                    id="g2369"
                                    transform="translate(117.7271,429.9492)"><path
                                        d="m 0,0 c 0,-19.703 -15.973,-35.676 -35.676,-35.676 -19.703,0 -35.676,15.973 -35.676,35.676 0,19.703 15.973,35.676 35.676,35.676 C -15.973,35.676 0,19.703 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2371" /></g><g
                                    id="g2373"
                                    transform="translate(465.5923,81.084)"><path
                                        d="m 0,0 c 0,-19.703 -15.973,-35.676 -35.676,-35.676 -19.703,0 -35.676,15.973 -35.676,35.676 0,19.703 15.973,35.676 35.676,35.676 C -15.973,35.676 0,19.703 0,0 Z"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2375" /></g><g
                                    id="g2377"
                                    transform="translate(500.6357,230.0811)"><path
                                        d="M 0,0 V 0"
                                        style="fill:none;stroke:#07BEB8;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-dasharray:none;stroke-opacity:1"
                                        id="path2379" /></g></g></g></g>
                    </svg>
                ',
                'steps' => json_encode([
                    [
                        'title' => 'Zrozumienie i Analiza Celów Klienta',
                        'description' => 'Na początku dokładnie omawiamy z klientem cele i oczekiwania związane z projektem inżynierii odwrotnej. Pozwala nam to zrozumieć specyfikę danego produktu lub komponentu oraz wyznaczyć kierunek prac.',
                    ],
                    [
                        'title' => 'Skanowanie i Digitalizacja Obiektu',
                        'description' => 'Rozpoczynamy od skanowania fizycznego obiektu, jeśli jest dostępny. Używamy zaawansowanych technologii skanowania 3D, aby uzyskać dokładny cyfrowy model obiektu do analizy.',
                    ],
                    [
                        'title' => 'Przetwarzanie i Rekonstrukcja Danych',
                        'description' => 'Po uzyskaniu danych 3D przystępujemy do ich przetwarzania. Obejmuje to rekonstrukcję brakujących elementów, korekty i optymalizację modelu, aby jak najlepiej odwzorować oryginalny obiekt.',
                    ],
                    [
                        'title' => 'Analiza Konstrukcyjna i Funkcjonalna',
                        'description' => 'Następnie przeprowadzamy szczegółową analizę konstrukcyjną i funkcjonalną obiektu. Badamy w jaki sposób poszczególne komponenty współpracują ze sobą, identyfikując kluczowe cechy i funkcje.',
                    ],
                    [
                        'title' => 'Modelowanie i Projektowanie Modyfikacji',
                        'description' => 'Na tej podstawie, w ścisłej współpracy z klientem, modelujemy ewentualne modyfikacje lub ulepszenia. Dąży to do zwiększenia wydajności, funkcjonalności lub kosztów produkcji.',
                    ],
                    [
                        'title' => 'Tworzenie Dokumentacji Technicznej',
                        'description' => 'Ostateczny model wraz z proponowanymi zmianami jest dokumentowany. Tworzymy kompletną dokumentację techniczną, która obejmuje rysunki wykonawcze, specyfikacje i szczegółowe opisy.',
                    ],
                    [
                        'title' => 'Konsultacje i Dostarczenie Wyników',
                        'description' => 'Wyniki naszej pracy, wraz z dokumentacją i zaleceniami, są prezentowane klientowi. Zapewniamy również wsparcie w interpretacji wyników i omawianiu możliwych kierunków ich zastosowania.',
                    ],
                ]),
                'date' => '04.02.2024',
                'order' => 50,
                'status' => true,
            ],
        ];
    }


    public function scopeActive($query)
    {
        return $query->where('status', true);
    }

    public function scopeOrdered($query)
    {
        return $query->orderBy('order', 'ASC');
    }
}
