<?php

use Artesaos\SEOTools\Facades\OpenGraph;
use Artesaos\SEOTools\Facades\SEOMeta;
use Artesaos\SEOTools\Facades\TwitterCard;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_homepage.css';
    $pathToJs = 'js/_homepage.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('Działania 3D w jednym miejscu');
    SEOMeta::setDescription('Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('Działania 3D w jednym miejscu');
    OpenGraph::setDescription('Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'homepage');

    TwitterCard::setTitle('Działania 3D w jednym miejscu');

    $realizations = \App\Models\Realization::active()->highlighted()->ordered()->get();
    $services = \App\Models\Service::active()->ordered()->get();

    return view('homepage', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'realizations' => $realizations,
        'services' => $services,
    ]);
})->name('homepage');

Route::get('/o-nas', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_about-us.css';
    $pathToJs = 'js/_about-us.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('O nas');
    SEOMeta::setDescription('Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('O nas');
    OpenGraph::setDescription('Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'about us');

    TwitterCard::setTitle('O nas');

    $breadcrumbs = [
        ['title' => 'O nas', 'url' => route('about-us')],
    ];

    return view('about-us', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('about-us');


Route::get('/uslugi', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_services.css';
    $pathToJs = 'js/_services.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('Usługi');
    SEOMeta::setDescription('Usługi: Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('Usługi');
    OpenGraph::setDescription('Usługi: Projektowanie CAD, Doradztwo Techniczne, Skanowanie 3D, Druk 3D, Dokumentacja Techniczna, Inżynieria odwrotna.');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'services');

    TwitterCard::setTitle('Usługi');

    $breadcrumbs = [
        ['title' => 'Usługi', 'url' => route('services')],
    ];
    $services = \App\Models\Service::active()->ordered()->get();

    return view('services', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'breadcrumbs' => $breadcrumbs,
        'services' => $services,
    ]);
})->name('services');

Route::get('/uslugi/{slug}', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_service.css';
    $pathToJs = 'js/_service.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    $slug = request()->slug;
    $service = \App\Models\Service::where('slug', $slug)->firstOrFail();

    // SEOmeta
    SEOMeta::setTitle(strip_tags($service->title));
    SEOMeta::setDescription($service->short_description);
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle(strip_tags($service->title));
    OpenGraph::setDescription($service->short_description);
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'service');

    TwitterCard::setTitle(strip_tags($service->title));

    $breadcrumbs = [
        ['title' => 'Usługi', 'url' => route('services')],
        ['title' => strip_tags($service->title), 'url' => route('service', [$service->slug])]
    ];

    return view('service', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'service' => $service,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('service');


Route::get('/realizacje', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_realizations.css';
    $pathToJs = 'js/_realizations.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('Realizacje');
    SEOMeta::setDescription('Realizacje Usługi Studia Inżynieryjnego Cadictive');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('Realizacje');
    OpenGraph::setDescription('Realizacje Usługi Studia Inżynieryjnego Cadictive');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'realizations');

    TwitterCard::setTitle('Realizacje');

    $realizations = \App\Models\Realization::ordered()->get();

    $breadcrumbs = [
        ['title' => 'Realizacje', 'url' => route('realizations')],
    ];

    return view('realizations', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'realizations' => $realizations,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('realizations');

Route::get('/realizacje/{slug}', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_realization.css';
    $pathToJs = 'js/_realization.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    $slug = request()->slug;
    $realization = \App\Models\Realization::active()->where('slug', $slug)->firstOrFail();
    $otherRealizations = \App\Models\Realization::active()->inRandomOrder()->where('slug','!=', $slug)->take(2)->get();

    // SEOmeta
    SEOMeta::setTitle(strip_tags($realization->title));
    SEOMeta::setDescription($realization->short_description);
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle(strip_tags($realization->title));
    OpenGraph::setDescription($realization->short_description);
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'service');

    TwitterCard::setTitle(strip_tags($realization->title));

    $breadcrumbs = [
        ['title' => 'Realizacje', 'url' => route('realizations')],
        ['title' => strip_tags($realization->title), 'url' => route('realization', [$realization->slug])]
    ];

    return view('realization', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'realization' => $realization,
        'otherRealizations' => $otherRealizations,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('realization');

Route::get('/kontakt', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_contact.css';
    $pathToJs = 'js/_contact.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('Kontakt');
    SEOMeta::setDescription('Kontakt z firmą Cadictive');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('Kontakt');
    OpenGraph::setDescription('Kontakt z firmą Cadictive');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'contact');

    TwitterCard::setTitle('Kontakt');

    $breadcrumbs = [
        ['title' => 'Kontakt', 'url' => route('contact')],
    ];

    return view('contact', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('contact');

Route::get('/polityka-prywatnosci', function () {
    // Convert CSS and JS to code
    $pathToCss = 'css/_privacy-policy.css';
    $pathToJs = 'js/_privacy-policy.js';
    $convertedCssFile = asset($pathToCss);
    $convertedJsFile = asset($pathToJs);
//    $convertedCssFile = convertCssFileToCode($pathToCss);
//    $convertedJsFile = convertJsFileToCode($pathToJs);

    // SEOmeta
    SEOMeta::setTitle('Polityka prywatności');
    SEOMeta::setDescription('Polityka prywatności CADICTIVE');
    SEOMeta::setCanonical(url()->current());

    OpenGraph::setTitle('Polityka prywatności');
    OpenGraph::setDescription('Polityka prywatności CADICTIVE');
    OpenGraph::setUrl(url()->current());
    OpenGraph::addProperty('type', 'contact');

    TwitterCard::setTitle('Polityka prywatności');

    $breadcrumbs = [
        ['title' => 'Polityka prywatności', 'url' => route('privacy-policy')],
    ];

    return view('privacy-policy', [
        'css' => $convertedCssFile,
        'js' => $convertedJsFile,
        'breadcrumbs' => $breadcrumbs,
    ]);
})->name('privacy-policy');

// Generate sitemap
Route::get('/sitemap.xml', [\App\Http\Controllers\SitemapXmlController::class, 'index']);

// Contact
Route::post('/contact-message', function (\App\Requests\ContactRequest $request) {
    try {
        $inputFullName = $request->get('inputFullName');
        $inputEmail = $request->get('inputEmail');
        $inputPhone = $request->get('inputPhone');
        $inputMessage = $request->get('inputMessage');
        $inputFile = $request->file('inputFile');

        \Illuminate\Support\Facades\Mail::to(config('mail.from.address'))->send(new \App\Mail\ContactForm($inputFullName, $inputEmail, $inputPhone, $inputMessage, $inputFile));
        \Illuminate\Support\Facades\Mail::to($inputEmail)->send(new \App\Mail\ContactForm($inputFullName, $inputEmail, $inputPhone, $inputMessage, $inputFile, true));
        return response()->json(['success'=>'Wiadomość została wysłana!']);

    } catch (\Exception $e) {
        \Illuminate\Support\Facades\Log::error($e);
        return response()->json(['error'=>'Coś poszło nie tak. Spróbuj później lub skontaktuj się w inny sposób.'], 500);
    }
})->name('contact.message');
